##
##  tusk.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg  0.7.3
%define       V_dist  20250106

#   package information
Name:         tusk
Summary:      Task Runner
URL:          https://rliebz.github.io/tusk/
Vendor:       Robert Liebowitz
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Building
License:      MIT
Version:      %{V_opkg}.%{V_dist}
Release:      20250106

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/tusk/tusk-%{V_dist}.tar.xz
Patch0:       tusk.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Tusk is a YAML-based task runner. By creating a tusk.yml in the
    root of a repository, Tusk becomes a custom command line tool with
    minimal configuration. It provides: Customizable: Specify your own
    tasks and options with support for command-line flags, environment
    variables, conditional logic, and more. Explorable: With help
    documentation generated dynamically and support for Bash and Zsh
    tab completion available, all the help you need to get started in
    a project is available straight from the command line. Accessible:
    Built for usability with a simple YAML configuration, familiar
    syntax for passing options, Bash-like variable interpolation, and a
    colorful terminal output.

%track
    prog tusk:release = {
        version   = %{V_opkg}
        url       = https://github.com/rliebz/tusk/releases
        regex     = tree/v(__VER__)
    }
    prog tusk:snapshot = {
        version   = %{V_dist}
        url       = http://download.openpkg.org/components/versioned/tusk/
        regex     = tusk-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n tusk
    %patch -p0

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/rliebz/tusk
    go build -v

%install
    #   install program
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin
    %{l_shtool} install -c -s -m 755 \
        src/github.com/rliebz/tusk/tusk \
        $RPM_BUILD_ROOT%{l_prefix}/bin/tusk

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

